Module error

Module error 

Enums

Error
Expected
What specifically the conversion functions were trying to encode/decode before they ran into an issue.
Mode
Used to describe the transcoding state. We define encoding as going to MUTF-8.
Position
The position of the current byte during the encoding/decoding phase. Only some of the positions are valid for some combinations of the bytes.

Type Aliases

Result